# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.1

import winrt.system
from winrt import _winrt_windows_perception_automation_core

__all__ = [
    "CorePerceptionAutomation",
]

CorePerceptionAutomation = _winrt_windows_perception_automation_core.CorePerceptionAutomation
